package com.persagy.apm.alarmservice.common.jms;

import com.persagy.apm.alarmservice.common.configuration.rabbitmq.JacksonMapper;
import com.persagy.apm.alarmservice.common.model.DmpMessage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.BindingBuilder;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.core.TopicExchange;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

/**
 * 消息发送者
 *
 * @author lixing
 * @version V1.0 2021/10/25 2:12 下午
 **/
@Slf4j
@Component
public class JmsSender {
    @Autowired
    private RabbitTemplate rabbitTemplate;

    /**
     * 交换机
     */
    private final String exchange = "exchange-alarm-service";

    /**
     * 报警条件路由键
     */
    private final String alarmConditionRoutingKey = "alarm-condition-routing-key";

    /**
     * 报警对象与报警条件关联关系路由键
     */
    private final String objConditionRelRoutingKey = "obj-condition-rel-routing-key";


    @Bean
    public TopicExchange exchange() {
        return new TopicExchange(exchange);
    }

    /**
     * 发送报警条件消息
     *
     * @param message 消息内容
     * @author lixing
     * @version V1.0 2021/10/25 2:18 下午
     */
    public void sendConditionMsg(DmpMessage message) {
        log.info("向rabbitMQ发送报警条件消息，message:" + JacksonMapper.toSimpleJson(message));
        rabbitTemplate.convertAndSend(exchange, alarmConditionRoutingKey, message);
    }

    /**
     * 发送设备与报警条件关联消息
     *
     * @param message 消息内容
     * @author lixing
     * @version V1.0 2021/10/25 2:18 下午
     */
    public void sendObjConditionRelMsg(DmpMessage message) {
        log.info("向rabbitMQ发送设备与报警条件关联消息，message:" + JacksonMapper.toSimpleJson(message));
        rabbitTemplate.convertAndSend(exchange, objConditionRelRoutingKey, message);
    }
}
